package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````2R4```````!``````````%BQ````
M`````````$``.``,`$``&0`8``8````$````0`````````!``````````$``
M````````H`(```````"@`@````````@``````````P````0```#@`@``````
M`.`"````````X`(````````9`````````!D``````````0`````````!````
M!````````````````````````````````````!@8````````&!@`````````
M$`````````$````%`````"``````````(``````````@````````^3(`````
M``#Y,@`````````0`````````0````0`````8`````````!@`````````&``
M``````!(10```````$A%`````````!`````````!````!@```#"L````````
M,+P````````PO````````#`$````````\!0`````````$`````````(````&
M````6*P```````!8O````````%B\````````H`$```````"@`0````````@`
M````````!`````0``````P`````````#``````````,````````P````````
M`#``````````"`````````!3Y71D!``````#``````````,``````````P``
M`````#``````````,``````````(`````````%#E=&0$````1)\```````!$
MGP```````$2?````````Y`````````#D``````````0`````````4>5T9`8`
M````````````````````````````````````````````````````````$```
M``````!2Y71D!````#"L````````,+P````````PO````````-`#````````
MT`,````````!`````````"]L:6(O;&0M;75S;"UX.#9?-C0N<V\N,0``````
M````!````"`````%````1TY5``$``<`$`````0`````````"``'`!`````$`
M````````$0```#X````$````"````"`<$``%0`2"*`!0!)"&`(2"(0`@20($
M";B"&4&Z!`(*/@```#\```!#````1P```$@```!.````3P```%$`````````
M50```%8```!7````60```%L```!=``````````````"CZ1D$:G^:?.K3[P[.
MWD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'
MQ@&[XY)\5<,\TL2YG$!GK\QF./*+',2)!9"(!W#30T75[#-BV^T5C"7,5J2;
MEJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````````````````
M```````````!````$@````````````````````````!1`0``$@``````````
M```````````````0````$@````````````````````````".`0``$@``````
M```````````````````8````$@`````````````````````````?````$@``
M``````````````````````#"`0``$@````````````````````````":`0``
M$@`````````````````````````H````(`````````````````````````!`
M````$@````````````````````````!&````$@``````````````````````
M``!-````$@````````````````````````">`@``$@``````````````````
M``````"/`@``$@````````````````````````#H`0``$@``````````````
M``````````!4````$@````````````````````````!N`@``$@``````````
M``````````````!;````$@````````````````````````!C````$@``````
M``````````````````!7`@``$@````````````````````````!K````$@``
M``````````````````````!Q````$@````````````````````````!Z````
M(`````````````````````````"(`@``$@````````````````````````"6
M````$@````````````````````````";````$@``````````````````````
M``!U`@``$@`````````````````````````5`@``$@``````````````````
M``````"B````$@`````````````````````````'`@``$@``````````````
M```````````6`P``$@`````````````````````````Y`@``$@``````````
M``````````````"]`@``$@````````````````````````"I````$@``````
M``````````````````"U`@``$@````````````````````````!?`0``$@``
M``````````````````````#!````(`````````````````````````#7````
M$@````````````````````````"``@``$@`````````````````````````E
M`@``$@````````````````````````#<````$@``````````````````````
M``#B````(`````````````````````````!B`@``$@``````````````````
M``````#\````$@````````````````````````!_`0``$@``````````````
M```````````!`0``$@````````````````````````!'`@``$@``````````
M``````````````!N`0``$@`````````````````````````'`0``$@``````
M```````````````````8`0``$@````````````````````````#C`0``$@``
M``````````````````````!L````$@````````````````````````#T`0``
M$@`````````````````````````N`@``$@````````````````````````"N
M`@``$@`````````````````````````>`0``$@``````````````````````
M``"F`@``$@````````````````````````#>`0``$@``````````````````
M```````R`0``$@`````````````````````````Y`0``$@``````````````
M``````````!*`0``$@````````````````````````#/`@``(0`6`(#`````
M````"`````````#*`@``$@`+`*`C````````JP$```````"O`0``$@`,`/%2
M`````````0````````!8`P``$@`+`*TQ````````S`4````````$!```$@`+
M`+4Y````````3P`````````U`P``$@`+`+PL````````!0````````#"`P``
M$@`(```@`````````0````````![`P``$@`+`'DW````````/`(```````#H
M`P``$@`+`,$L````````FP$```````"S`P``$``6`&#`````````````````
M``!&`P``$@`+`!LQ````````D@````````!E`P``$@`+`&@K````````*P``
M``````!M`P``$@`+`,`P````````1`````````"1`P``$@`+`'%0````````
M]P````````"F`P``$@`+`%PN````````%@````````#_`P``$``6`"#1````
M``````````````#[`@``$@`+`&$E````````(P````````#0`@``$0`6`(#`
M````````"`````````#(`P``$@`+`'(N````````J0`````````)````$0`2
M`%"\````````"`````````#1`@``(0`6`(#`````````"`````````"<`P``
M$0`5`%C`````````"`````````#A`P``$``5`&#```````````````````"X
M`P``$``+`$LE``````````````````"_`P``$@`+`"-0````````3@``````
M``#3`0``$0`6`(C`````````!`````````#2`@``(0`6`(#`````````"```
M```````$`P``$@`+``0Q````````%P````````"R````(@``````````````
M```````````?`P``$@`+`-<K````````Y0````````#U`P``$@`+`&A1````
M````10$```````"U`0``$0`6`&#``````````0````````#4`P``$@`+`!LO
M````````I0$`````````;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E9&ER
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C
M:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I
M;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D
M`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C
M:69I8P!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?
M=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A
M9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB
M8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM
M>#@V7S8T+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C
M;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?
M<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N
M86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA
M;`!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#
M3U)%`````,`````````(``````````#`````````(,`````````(````````
M`.)@````````*,`````````(`````````-M@````````,,`````````(````
M`````!YB````````.,`````````(`````````/A@````````0,`````````(
M`````````"9B````````6,`````````(`````````+9B````````P+\`````
M```&````"0``````````````R+\````````&````%P``````````````T+\`
M```````&````6@``````````````V+\````````&````)0``````````````
MX+\````````&````*@``````````````Z+\````````&````+P``````````
M````\+\````````&````,```````````````^+\````````&````-0``````
M````````4+P````````%````40``````````````8,`````````%````70``
M````````````@,`````````%````3P``````````````B,`````````%````
M5P``````````````$+X````````'`````0``````````````&+X````````'
M`````@``````````````(+X````````'`````P``````````````*+X`````
M```'````!```````````````,+X````````'````!0``````````````.+X`
M```````'````!@``````````````0+X````````'````!P``````````````
M2+X````````'````"```````````````4+X````````'````"@``````````
M````6+X````````'````"P``````````````8+X````````'````#```````
M````````:+X````````'````#0``````````````<+X````````'````#@``
M````````````>+X````````'````#P``````````````@+X````````'````
M$```````````````B+X````````'````$0``````````````D+X````````'
M````$@``````````````F+X````````'````$P``````````````H+X`````
M```'````%```````````````J+X````````'````%0``````````````L+X`
M```````'````%@``````````````N+X````````'````&```````````````
MP+X````````'````&0``````````````R+X````````'````&@``````````
M````T+X````````'````&P``````````````V+X````````'````'```````
M````````X+X````````'````'0``````````````Z+X````````'````'@``
M````````````\+X````````'````'P``````````````^+X````````'````
M(````````````````+\````````'````(0``````````````"+\````````'
M````(@``````````````$+\````````'````(P``````````````&+\`````
M```'````)```````````````(+\````````'````)@``````````````*+\`
M```````'````)P``````````````,+\````````'````*```````````````
M.+\````````'````*0``````````````0+\````````'````*P``````````
M````2+\````````'````+```````````````4+\````````'````+0``````
M````````6+\````````'````+@``````````````8+\````````'````,0``
M````````````:+\````````'````,@``````````````<+\````````'````
M,P``````````````>+\````````'````-```````````````@+\````````'
M````-@``````````````B+\````````'````-P``````````````D+\`````
M```'````.```````````````F+\````````'````.0``````````````H+\`
M```````'````.@``````````````J+\````````'````.P``````````````
ML+\````````'````/```````````````N+\````````'````/0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!0Z*H&``#HI3(``%C#````_S7JG0``_R7LG0``#Q]``/\EZIT``&@`````
MZ>#_____)>*=``!H`0```.G0_____R7:G0``:`(```#IP/____\ETIT``&@#
M````Z;#_____)<J=``!H!````.F@_____R7"G0``:`4```#ID/____\ENIT`
M`&@&````Z8#_____);*=``!H!P```.EP_____R6JG0``:`@```#I8/____\E
MHIT``&@)````Z5#_____)9J=``!H"@```.E`_____R62G0``:`L```#I,/__
M__\EBIT``&@,````Z2#_____)8*=``!H#0```.D0_____R5ZG0``:`X```#I
M`/____\E<IT``&@/````Z?#^____)6J=``!H$````.G@_O___R5BG0``:!$`
M``#IT/[___\E6IT``&@2````Z<#^____)5*=``!H$P```.FP_O___R5*G0``
M:!0```#IH/[___\E0IT``&@5````Z9#^____)3J=``!H%@```.F`_O___R4R
MG0``:!<```#I</[___\E*IT``&@8````Z6#^____)2*=``!H&0```.E0_O__
M_R4:G0``:!H```#I0/[___\E$IT``&@;````Z3#^____)0J=``!H'````.D@
M_O___R4"G0``:!T```#I$/[___\E^IP``&@>````Z0#^____)?*<``!H'P``
M`.GP_?___R7JG```:"````#IX/W___\EXIP``&@A````Z=#]____)=J<``!H
M(@```.G`_?___R72G```:",```#IL/W___\ERIP``&@D````Z:#]____)<*<
M``!H)0```.F0_?___R6ZG```:"8```#I@/W___\ELIP``&@G````Z7#]____
M):J<``!H*````.E@_?___R6BG```:"D```#I4/W___\EFIP``&@J````Z4#]
M____)9*<``!H*P```.DP_?___R6*G```:"P```#I(/W___\E@IP``&@M````
MZ1#]____)7J<``!H+@```.D`_?___R5RG```:"\```#I\/S___\E:IP``&@P
M````Z>#\____)6*<``!H,0```.G0_/___R5:G```:#(```#IP/S___\E4IP`
M`&@S````Z;#\____)4J<``!H-````.F@_/___R5"G```:#4```#ID/S___\E
M.IP``&:0_R5"G```9I#_)4*<``!FD```````````051(@^P@B7PD'$B-?"0<
M2(ET)!!(C70D$$B)5"0(2(U4)`CH:/[__TB+-2F<``!(BST:G```2(GRZ`+]
M__^`/7N<````=37HM/W__TB)!26M``!(B<=(A<!U"K\!````Z#O^___HEO[_
M_XL]>)P``.@+____QH#7"0```(L]9IP``.CY_O__BSU;G```@(@J!````NCG
M_O__BWPD'("(*@0```%$C6<#@\<$2&/_2,'G`^@I_O__2(MT)!"+?"0<2(G!
M2(D%IJP``$B+!DB)`4B-!3D^``!(B4$(2(L%UIL``$B)01!(C04F/@``2(E!
M&#'`C5`$2/_`2&/22(T4T3G'?@E,BP3&3(D"Z^9(QP(`````13'`1(GB2(L]
M5ZP``$B--<L&``#H<_S__T&)Q(7`=0](BST]K```Z(#]__]!B<1(BSTNK```
MZ`']__\QP$B-/9T[``#H<0(``$B%P'4N2(,]_JL```!U$TB-/3<[``#H5@(`
M`$B)!>FK``!(BSWBJP``2(7_=`7HA10``$B+/>&K``#H!/[__^CO^O__2(/$
M($2)X$%<PT@Q[4B)YTB--0"7``!(@^3PZ`````"+-TB-5PA,C06#+0``13')
M2(T-B/K__TB-/2'^___I?/S__V8N#Q^$``````!FD$B-/<F:``!(C07"F@``
M2#GX=!5(BP4>F@``2(7`=`G_X`\?@`````###Q^``````$B-/9F:``!(C362
MF@``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!?69``!(A<!T"/_@9@\?1```
MPP\?@`````#S#Q[Z@#V5F@````^%EP```%5(@SVVF0```$B)Y4%44W0,2(L]
MUYD``.A:_?__2(T%"Y8``$B-'0R6``!(*<-)B<1(BP5?F@``2,'[`TB#ZP%(
M.=AS)68N#Q^$``````!(@\`!2(D%/9H``$'_%,1(BP4RF@``2#G8<N7H$/__
M_TB#/3B9````=`Q(C3WO>0``Z.K\__];05S&!0":```!7<-F#Q]$``###Q^`
M`````/,/'OI(@ST<F0```'0B54B--?J9``!(C3VS>0``2(GEZ+O\__]=Z>7^
M__\/'T0``.G;_O__05=!5D%5051%,>154U%(A?]T9TR+-8&9``!-A?9T6TF)
M_4F)]TB)^(H0A-)T"H#Z/70%2/_`Z_!$*>A,B?5(8]A,BV4`387D=#!(B=I,
MB>Y,B>?H\_G__X7`=1A!@#P</7413"GU38UD'`%(P?T#08DOZP9(@\4(Z\=:
M3(G@6UU!7$%=05Y!7\-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z%G___](
MBU0D"&1(*Q0E*````'0%Z+_[__](@\08PU532(G[2(/L&&1(BP0E*````$B)
M1"0(,<!(C6PD!#'`2(GN2(G?Z!3___](A<!T(DAC5"0$2(L%GI@``$B-!-!(
MBU`(2(D02(72=-)(@\`(Z^Y(BT0D"&1(*P0E*````'0%Z%/[__](@\086UW#
M059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_P^$X@```(`_
M`$B)_0^$U@```.C0]___2(T=JC<``$F)Q4B%P`^$O@```$R)[^AE^/__2(7`
M#X2=````3(U@$TB)WDR)Y^@]^/__A<!TW$B--7(W``!,B>?H*OC__X7`=,E(
MB>_HKOK__TR)YTF)QNBC^O__08U\!@)(8__H5OC__TR)X4B)ZDB--3PW``!)
MB<9(B<<QP.A<^O__3(GW2(UT)`CH#_K__TR)]__`=!>+1"0@)0#P```]`$``
M`'4'Z!?____K!>C\]___3(GWZ-3Y___I4O___TR)[^A'^/__2(GOZ(_Y__](
MBX0DF````&1(*P0E*````'0%Z"?Z__](@<2@````6UU!7$%=05[#2('LN```
M`&1(BP0E*````$B)A"2H````,<!(C70D&$B)?"0(Z-[W__^%P'4SBU0D,$B+
M?"0(@>(`\```@?H`0```=`B!^@"@``!U%KX"````Z,'V__^%P`^4P`^VP.L"
M,<!(BY0DJ````&1(*Q0E*````'0%Z)WY__](@<2X````PT%7059!54%454B)
M_5-(B?-(@^P89$B+!"4H````2(E$)`@QP(`^/74#2/_#2(G?Z%'Y__](C70D
M!$B)[TF)Q#'`Z-3\__])B<5(A<!T)TB)Q^@O^?__23G$#X>K````,<"*%`-!
MB%0%`$C_P(32=?'I!`$``$R+/3F6```QP$&)Q4C_P$F#?,?X`'7R08UU`DAC
M]DC!Y@.#/9>F````=!E,B?_HS?7__TB)!0:6``!(A<!U/.G`````QP5RI@``
M`0```$B)]^AZ]O__28G&2(7`#X2B````26/53(G^2(G'2,'B`^AL]O__3(DU
MQ94``$B+%;Z5``!!C44!1(EL)`1(F$C'!,(`````2(GHBA"$TG0*@/H]=`5(
M_\#K\$@IZ$QC;"0$2(L5B94``$B828U\!`).C33JZ`GV__])B09(A<!T-4B+
M!6J5``!*BP3HBE4`2/_%2(G!2/_`B%#_A-)T!8#Z/77HQ@$],=**#!.(#!!(
M_\*$R77S2(M$)`AD2"L$)2@```!T!>@'^/__2(/$&%M=05Q!74%>05_#4(L]
M&94``.BL]___2(L5;90``$%82(T-M',``$B)QTB--7LT``#I;??__U"+/>Z4
M``#H@??__TB)Q^C!____BSW;E```Z&[W__],C07V-@``13')05I(B<=,B<%(
MC16N"P``2(TU4S0``.FI]/__05154TB![!`@``!D2(L$)2@```!(B80D""``
M`#'`3(UD)`;HL?3__TR-!30T``"^`1```$R)YXG!2(T5)S0``#'`Z%+T__^#
M^/]U!#'`ZW%(F$@]`!```'8"#PM(C:PD!Q```+H`$```3(GG2(GNZ,7U__](
MB<.%P'C1C7@!2&/_Z+/T__](A<!TP4ACTT@YZ',)2(T,$$@YS7*^2#GH=@I(
MC4P5`$@YR'*O@?L!$```?Z>)T4B)QTB)[O.DQ@00`$B+E"0((```9$@K%"4H
M````=`7HL/;__TB!Q!`@``!;74%<P^D6____05=!5D%5051)B?Q(C3UW,P``
M54B)]5-(@>RH$```9$B+!"4H````2(F$))@0```QP.AW^O__OB\```!,B>=(
MB</HN?3__TB%P'063(GF2(T]/3,``#'`Z*[\___I#0$``$R)YTR--30S``#H
M'_;__TB)[T&)Q>@T]/__3(GV2(G'Z,GU__])B<=(A<!TO4&`/P!U!TR-/:4R
M``!(A=MT$TR)_DB)W^A4\___A<`/A+$```!,B?_HU/7__XUP_TACUDP!^H`Z
M+W4'Q@(`B?#KZT*-1"@!/?\/```/CVO___](C:PDF````$V)X4R)^3'`3(T%
MJC(``$B-%9(S``"^`!```$B)[^BD\O___\`]`!```'8"#PM(C70D"$B)[^@,
M]?__A<!U/8M$)"`E`/```#T`@```=2V^`0```$B)[^A;\O__A<!U'$B)[DB-
M/4`R``#HL_O__TB)[^A0\___28G$ZPI,B?8Q_^D3____2(N$))@0``!D2"L$
M)2@```!T!>@9]?__2('$J!```$R)X%M=05Q!74%>05_#2(GXBA>$TG0,2/_'
M@/HO2`]$Q^ONPTB%_P^$E````%6`/P!(B?UT/.C']/__2(U4!?](.=5S&X`Z
M+W412/_*Z_&`.B](C4+_="E(B<)(.=5R[T@YU74<@'T`+TB-/:0Q``!U!TB-
M/3HQ``!=ZTR`.B]U"$C_RD@YU7+S2"GJ2(U"`D@]`!```'<E2/_"2('Z`!``
M`'8"#PM(B>Y(C2T"D@``2(GOZ!KS__](B>CK`C'`7<-(C3WK,```Z57R__]!
M5DB-->QO``"Y(@```$R--7LQ``!!54R-+1$Q``!!5$R-)4,Q``!52(TM5S$`
M`$B#[#AD2(L$)2@```!(B40D*#'`2(U\)`;SI$B-/?@P``#H-?C__S'`2(T]
M\S```.@G^/__,<!(C3WM,```Z!GX__\QP$B-/>@P``#H"_C__S'`3(GGZ`'X
M__\QP$B-/><P``#H\_?__S'`3(GOZ.GW__\QP$B)[^C?]___,<!,B??HU??_
M_S'`2(T]VS```.C']___,<!(C3UK,```Z+GW__\QP$B-/<DP``#H<_?__TB%
MP'0-2(G&3(GW,<#HOOG__TB-/;PP```QP.A3]___2(G&2(7`=`Y(C3VX,```
M,<#HFOG__TB-/;4P```QP.@O]___3(GO2(G&2(7`=1E(C3VL,```,<#H%O?_
M_TB)QDB%P'0'2(GO,<#K(DB-?"07N@H```!(C366,```Z+/P__^%P'4-2(UT
M)"%(B>_H/?G__S'`2(TU@C```$R)Y^@L^?__2(M$)"AD2"L$)2@```!T!>BL
M\O__2(/$.%U!7$%=05[#@SV)CP``_W4T44B-/=`O```QP.B6]O__,=)(A<!T
M$(H`/#`/E<$QTH3`#Y7"(<J)%5N/``"+!56/``!:PXL%38\``,-1Z&;R__^)
MQ^C/\/__2(7`=`-(BP!:PT%53(TM]R\``#'`051)B?Q,B>]54U'H./;__TR)
MYDB%P'16@#@`2(G#=$Y(B<?H0O#__TB%P'523(GGZ/7Q__](B=](B<7HZO'_
M_TB-?`4"Z*#O__](C37:+P``28G83(GB2(G%2(G'2(T-UBX``#'`Z)_Q__](
MB>Y:3(GO6S'`74%<05WI)OC__UA;74%<05W#05=(C35JC@``28G_N0P```!!
M5D%505154TB![%B!``!D2(L$)2@```!(B80D2($``$B-!4TO``!(C7PD2$C'
M1"0H`````/.E2(T]3BX``$C'1"1``````$B)1"082(T%\"T``$B)1"0@2(T%
M&B\``$B)1"0P2(T%$R\``$B)1"0X,<#H.?7__TB%P'1`@#@`2(G%=#A(B<?H
MT?[__TB+A"1(@0``9$@K!"4H````#X7^!```2('$6($``$B)[UM=05Q!74%>
M05_I]N[__S'`2(UL)##H?O[__TB)PTB%P'4Y2(M]`$B%_W0I,<#HT/3__TB)
MQTB%P'4&2(/%".OB@#@`=/7HNN[__TB)PTB%P'3HZP=(C1UD+@``2(G?3(TM
M="X``.AZ\/__2(U\``'H,.[__TF)Q$B)Q0^V$X32=!9(B>],B>XQP$C_P^@S
M\/__2(/%`NOC2(U<)$A(BQ-(A=)T+DB)US'`Z%3T__](B<5(A<!T(X`X`'0>
M2(G'Z!KV__^%P'022(GOZ#7N__](B<)(C5PD&.LY2(/#".N]2(LK2(7M=#"`
M?0``="I(B>](B50D".CC]?__2(M4)`B%P'0+2(GOZ/GM__](B<)(@\,(2(72
M=,A(B==(B50D"$R--=`L``#HN>___TR)YTB)P^BN[___C:P#!`0``$AC[4B)
M[^A<[?__2(M4)`A-B>%,B?%(B<=)B<4QP$R-!7PM``!(C35Z+0``Z%;O__^^
MP`$``$R)[^CI[O___\!U*^C0[O__1(L`08/X$70=28L72(L]38@``$R)Z3'`
M2(TU22T``.@\[O__ZRY(C70D>$R)[^@M[?__B<.%P'0C28L72(L]'8@``$R)
MZ3'`2(TU5"T``.@,[O__13'DZ0`#``"+A"20````)0#P```]`$```'7*1(ND
M))0```#H!.___T$YQ'6XBX0DD````"7_`0``/<`!``!UI4B)[^B$[/__2(T]
MDRP``$F)Q#'`Z-'R__](B<9(A<!U!4F++^L028L_Z`_X__](B<5(A<!TZTB)
M[^B.[O__2(G"@_@#?F%(F$B--1,M``!(B50D"$B-?`7\Z-[K__^%P'5%2(M4
M)`B#^@1T#8/J!4ACTH!\%0`O=2Y-BW\(387_="5,B?_H0N[__TB#^`-V%TF-
M?`?\2(TURRP``.B;Z___A<!)#T3O,<#HCOO__X7`#X5J`0``2(GO,?;H/.S_
M_XG%A<`/A%8!``"Z`@```$C'QN[___^)Q^@_Z___2(V<)$@!``"Z!@```(GO
M2(G>Z!CM__^`O"1(`0```'5C@+PD20$``$-U68"\)$H!``!!=4^`O"1+`0``
M0W5%@+PD3`$``$AU.X"\)$T!``!%=3&Z`@```$C'QL;___^)[^C9ZO__NBD`
M``!(B=Z)[^BZ[/__3(T-TBP``$F)V.FC````,=(Q]HGOZ+#J__\QP.@L&@``
M28G'N@"```!(B=Z)[^B'[/__B<*%P'X-2(G>3(G_Z%<:``#KWHGO2(V<)`L!
M```Q[>A#[/__3(G^2(G?3(V\)!\!``#H*!L``$V)^$B-#?LJ```/MA0K2(G.
M3(G_,<!(_\5,B40D"$F#QP+HR>S__TB#_11,BT0D"$B-#<XJ``!UT<:$)$<!
M````3(T-)RP``$R)\4R)ZDB--5LK``!,B><QP.B1[/__Z8<```!(C35N*@``
M2(T][RD``#'`Z!+S__](C2WO*P``Z.OI__],B?%,B>I,B>=!B<!,C0W7*P``
M2(TU("L``#'`Z$KL__^^P`$``$R)Y^C=Z____\!U-.C$Z___@S@1=2KHJNG_
M___#3(GQ3(GJ08G`4$&)V4B--?$J``!53(GG,<#H">S__UI9Z[M,B>_HK>O_
M_TB-/1`I``!,B>8QP.B'\O__3(GGZ,_Y__](BX0D2($``&1(*P0E*````'0%
MZ/SK__](@<18@0``3(G@6UU!7$%=05Y!7\-!5(L]!XD``%53Z)CK__^+/?J(
M``!(B</HBNO__XJ3L````$B-/>(H``"(D+$````QP.B^[___2(7`=`N`.#%U
M!H!X`0!T!S'`Z%3W__^+/;N(``#H3NO__[D#````N@$```!(C35'*@``2(G'
MZ,7I__](B<-(A<!T1TB+0!"+/8N(``!(BRCH&^O__TB-%2`J``!(B<=(B>[H
MN>G__TB+0Q!(BRCV10Y`=!:+/5Z(``#H\>K__TB)[DB)Q^BVZ/__BSU(B```
MZ-OJ__^Y`P```+H!````2(TUVRD``$B)Q^A2Z?__2(G#2(7`='Q(C3WF)P``
M,<#H^N[__TF)Q$B%P'0/2(M#$(L]`H@``$B+*.M$Z$?S__^+/?*'``!(A<!(
MB<5(BT,0="!,BR#H=NK__TB)ZDB)QTR)YN@8Z?__2(GOZ"#J___K($B+%4>8
M``!(BRA,BR+H3.K__TR)XDB)[DB)Q^CNZ/__BSV@AP``Z#/J__^Z`0```$B-
M-3HI``!(B<?H3^?__XL]@8<``$B)Q>@1ZO__2(T5,BD``$B)[DB)Q^BOZ/__
MBSUAAP``Z/3I__](C3T7)P``QH"Q`````#'`Z"WN__](B07`EP``2(7`=21(
MBSV\EP``Z%3X__](B06HEP``2(7`=0Q(C3WB*```Z!_G__](BSV0EP``OL`!
M``#H3NG__XG!C4`!@_@!=B2#^1%T'TB+!7B7``!(BQ5IEP``2(T]R2@``$B+
M,#'`Z.#F__];74%<PU5(B?U34>BR]/__2(G'Z)3T__](B<,QP.CN]O__A<!T
M*DB%[70E@'T``'0?2(TU8B<``$B)W^B@Y___2#G#=0M:2(GO6UWI%.[__UA;
M7<-!5TB)_C'2059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP(M$
M%CA(BWP6.`_(B<!(B?E(B414"$B)^$C!Z2!(P>@H2,'O."4`_P``2`GX2(G/
M2,'A"$C!YQB!X0``_P")_T@)^$@)R$B)1%002(/""$B#^D!UK$B-5"0(2(V\
M)`@"``!(BT)H2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?"<A(B4)X2#GZ==E,
MBPY,BUX02(M^($B+7AA,B<A,B<I(BVX(2(M,)!!(P>H;2,'@!4@)T`-$)`A(
MC8P+F7F"6HV4.)EY@EI,B=A(,=A((>A(,=A$C10"2(GJ2(GH2,'H`DC!XAY,
MB==("<),B=A(P>\;08G03#'`3"'(3#'82`'(3(G12,'A!4@)^4B+?"081(TD
M"$R)R$R)R4C!Z0)(P>`>28V\.YEY@EI-B>5("<A)P>T;2#'"B<%,(=),,<)(
M`?I,B>=(P><%3`GO3(ML)"`!UTR)TDG!Z@)(P>(>B?]/C80HF7F"6DP)TDF)
M_4@QT$&)TDPAX$G![1M(,<A,`<!)B?A)P>`%30GH3(ML)"A!`<!,B>!)P>P"
M2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$@A^DPQTD@!RDR)P4C!
MX05,">E,BVPD,`'12(GZ2,'O`DC!XAZ)R4^-E"J9>8):2`GZ28G-2#'02<'M
M&XG73"'`3#'@3`'028G*2<'B!4T)ZDR+;"0X00'"3(G`2<'H`DC!X!Y%B=)/
MC:0LF7F"6DP)P$V)U4@QPDG![1M!B<!((<I(,?I,`>)-B=1)P>0%30GL3(ML
M)$!!`=1(B<I(P>D"2,'B'D6)Y$J-O"^9>8):2`G*38GE2#'02<'M&XG13"'0
M3#'`2`'X3(GG2,'G!4P)[TR+;"1(`<=,B=!)P>H"2,'@'HG_3XV$*)EY@EI,
M"=!)B?U(,<))P>T;08G"3"'B2#'*3`'"28GX2<'@!4T)Z$R+;"1000'03(GB
M2<'L`DC!XAY%B<!*C8PIF7F"6DP)XDV)Q4@QT$G![1M!B=1((?A,,=!(`<A,
MB<%(P>$%3`GI3(ML)%@!P4B)^$C![P)(P>`>B<E/C90JF7F"6D@)^$F)S4@Q
MPDG![1N)QTPAPDPQXDP!TDF)RDG!X@5-">I,BVPD8$$!TDR)PDG!Z`)(P>(>
M18G23XVD+)EY@EI,"<)-B=5(,=!)P>T;08G02"'(2#'X3`'@38G42<'D!4T)
M[$R+;"1H00'$2(G(2,'@'DC!Z0)%B>1*C;POF7F"6D@)R$V)Y4@QPDG![1N)
MP4PATDPQPD@!^DR)YTC!YP5,">],BVPD<`'73(G22<'J`DC!XAZ)_T^-A"B9
M>8):3`G228G]2#'02<'M&T&)TDPAX$@QR$P!P$F)^$G!X`5-">A,BVPD>$$!
MP$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$2"'Z3#'2
M2`'*3(G!2,'A!4P)Z4R+K"2``````=%(B?I(P>(>2,'O`HG)3XV4*IEY@EI(
M"?I)B<U(,=!)P>T;B==,(<!,,>!,`=!)B<I)P>(%30GJ3(NL)(@```!!`<),
MB<!)P>@"2,'@'D6)TD^-I"R9>8):3`G`38G52#'"2<'M&T&)P$@ARD@Q^DP!
MXDV)U$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"20````2,'B'D@)RDJ-O">9>8):
M38GL2#'02<'L&XG13"'03#'`2`'X3(GO2,'G!4P)YTR+I"28`````<=,B=!(
MP>`>2<'J`HG_3XV$()EY@EI,"=!)B?Q(,<))P>P;08G"3"'J2#'*3`'"28GX
M2<'@!4T)X$6)P$P!PDV)Z$G![0))P>`>08G430GH3(NL)*````!,,<!((?A*
MC8PIF7F"6DV)Y4PQT$G![1M(`<A,B>%(P>$%3`GIB<E(`<A(B?E(P>\"2,'A
M'D&)Q4@)^4R)QT6)P$@QSS'72(N4)*@```!)C902H>O9;DV)ZD@!UTR)ZDG!
MZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L`D&)^DP#A"2P````3`GB28G,B<E(
M`XPDN````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$R)
MZ$G![0)(P>`>18G@3`GH28G5B=)(`Y0DP````$DQQ40Q[TR-K#FAZ]EN3(G!
M3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!),<I%
M,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)
MXDP)PDF)R$@#A"3(````B<E),=!(`XPDT````$4QZ$Z-K`"AZ]EN3(G038G0
M2<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0DV```
M`$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(
MP>$>1(GG3`G128G"B<!(`X0DX````$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J
M&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPDZ```
M`$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$B)^$C![P)(P>`>
M18G@2`GX2(G7B=)(`Y0D\````$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!
MX05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D^````$DQRD4Q
MXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB
M3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)``!``!,
M"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D"`$``$@QQT0QYTR-
MI#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G1
M28G"B<!(`X0D$`$``$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)
MTDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)T$V)
MT$G!Z!M(P>`%3`G`2`.,)!@!``")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7
MB=)(`Y0D(`$``$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!
MS4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D*`$``$DQRD4QXDZ-I!*AZ]EN
M2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E)
M,=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>`>2,'O
M`D6)Z$@#C"0P`0``2`GX2(G7B=)(`Y0D.`$``$@QQT0QYTV)Q$B-C#FAZ]EN
M3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D'HG_30G428G"2`'YB<!-,>*)ST@#
MA"1``0``13'J28G]3HV4$J'KV6Y(B?I)P>T;2,'B!4P)ZD$!TDR)PDG!Z`)(
MP>(>18G23`G"38G@18GD23'028G608G51#'!38G02(V,"*'KV6Y,B=!)P>@;
M2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](P>$>2`GY20G.B<]((?I-(=9)"=9(
MBY0D2`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J`DC!
MXAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D4`$``$D!QDT!]4V)YDP!
MZ4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-
M(>9,(<),"?),B[0D6`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,
MB>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)&`!``!)`<9-
M`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI
M08G-20G.22'^3"'J3`GR3(NT)&@!``!)`<9-`?!-B=9,`<)-B=!)P>`%2<'N
M&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0D
M<`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!
MX1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D>`$``$D!QDT!]4V)YDP!ZDV)
MY4G![AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-(=9,
M(>%,"?%,B[0D@`$``$D!QDP!]TV)[D@!^4R)[TG![AM(P><%3`GW28G6`<],
MB>%)P>P"2,'A'HG_3`GA08G,20G.32'N3"'B3`GR3(NT)(@!``!)`<9-`?))
MB?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G128G6
M08G52"'Y32'F3`GQ3(NT))`!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@!4T)
M\$F)UD$!R$B)^4C![P)(P>$>18G`2`GYB<])"<Y-(=9((?I,"?),B[0DF`$`
M`$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%B>1,
M"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0DH`$``$D!QDT!]4V)YDP!Z4V)Y4G!
M[AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),
M"?),B[0DJ`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"
M2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)+`!``!)`<9-`?))B?Y,
M`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.
M22'^3"'J3`GR3(NT)+@!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)\$$!
MT$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0DP`$``$D!
MQDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,
M"=%)"<Y!B<I-(<9,(=),"?),B[0DR`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)
MP>4%30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,"<%,
MBX0DT`$``$D!P$P!QTV)Z$@!^4R)[TG!Z!M(P><%3`G'1(T$.4R)YTG![`)(
MB=%(P><>3`GG08G\2`GY3"'I3"'B2`G*2(N,)-@!``!(`<%,`=%-B<)(`X0D
MX`$``$@!RDR)P4G!ZAM,`?A(P>$%3(N\)"`"``!,"=&)R4@!RDR)Z4G![0)(
MP>$>08G23`GI2`G/28G-08G.3"''32'E20G]3(G73`'H38G52,'G!4G![1M,
M">]-B<5)P>@"2<'E'HG_30GH3(NL).@!``!(`?A,,<&)QS'1NM;!8LI)`=5-
M`>Q)B?U,`>%)B?Q)P>T;2<'D!4T)[$V)U46)Y$P!X4G!Y1Y)P>H"08G,30GJ
M38G%18G`33'51#'H3(NL)/`!``!)`=5-`?5-B>9,`>A-B>5)P>X;2<'E!4T)
M]4F)_DC![P))P>8>18GM3`GW3(NT)/@!``!,`>A!B<5)`=9-`?!-B=9%B=))
M,?Y$,?%-B>Y)`<A,B>E)P>X;2,'A!4P)\8G)20'(3(GA2<'L`DC!X1Y%B<9,
M">%,BZ0D``(``$D!U$T!XDF)_(G_23',1#'@38GT20'"3(GP2,'@!4G![!M,
M">")P$D!PDR)Z$G![0)(P>`>18G420G%2(N$)`@"``!(`=!(`<=(B<B)R4PQ
MZ$0QP$V)X$@!QTR)X$G!Z!M(P>`%3`G`B<!(`<=,B?!)P>X"2,'@'D&)^$P)
M\$R+M"00`@``20'63`'Q38GN18GM23'&13'R38G&20'*3(G!2<'N&TC!X05,
M"?&)R4D!RDR)X4G![`)(P>$>18G620G,2(N,)!@"``!(`=%)`<U(B<%)`==,
M,>$Q^4R)]TD!S4R)\4C![QM(P>$%2`GYB<E)`<U,B<%)P>@"2,'A'D2)[TP)
MP4&)P$R)X$6)Y$@QR$T!^$R+O"0P`@``1#'028GZ20'`2(GX2<'J&TC!X`5,
M"=")P$D!P$R)\$G![@)(P>`>18G"20G&2(N$)"@"``!(`=!)`<1(B<A,,?!$
M,>A-B=5)`<1,B=!)P>T;2,'@!4P)Z(G`20'$2(GX2,'@'DC![P))`==%B>5(
M"?B)STR)\46)]D@QP4P!_T0QP4V)Z$@!STR)Z4G!Z!M(P>$%3`G!B<E(`<],
MB=%)P>H"2,'A'D&)^$D)RDB+C"0X`@``2`'120'.2(G!B<!,,=%$,>%-B<1)
M`<Y,B<%)P>P;2,'A!4P)X8G)20'.3(GI2<'M`DC!X1Y%B?1,">E,BZPD0`(`
M`$D!U4P!Z$V)U46)TDDQS40Q[TV)Y4@!QTR)X$C!X`5)P>T;3`GHB<!(`<=,
MB<!)P>@"2,'@'D&)_4D)P$B+A"1(`@``2`'020'"2(G(B<E,,<!$,?!-B>Y)
M`<),B>A)P>X;2,'@!4P)\(G`20'"3(G@2<'L`DC!X!Y%B=9,">!,BZ0D4`(`
M`$D!U$P!X4V)Q$6)P$DQQ$0QYTV)]$@!STR)\4G![!M(P>$%3`GAB<E(`<],
MB>E)P>T"2,'A'D&)_$D)S4B+C"18`@``2`'120'(2(G!B<!,,>E$,=%-B>))
M`<A,B>%)P>H;2,'A!4P)T8G)20'(3(GQ2<'N`DC!X1Y%B<),"?%,B[0D8`(`
M`$D!UDP!\$V)[D6)[4DQSD0Q]TV)UD@!^$R)UTG![AM(P><%3`GW38GF2<'L
M`DG!YAZ)_TT)]$R+M"1H`@``2`'XB<=)`=9-`?5)B<Z)R4TQYD4Q\$F)_DT!
MQ4F)^$G![AM)P>`%30GP38G618G`30'%2<'F'DG!Z@)%B>A-"?),B[0D<`(`
M`$D!UDP!\4V)YD6)Y$TQUD0Q\$V)QD@!P4R)P$G![AM(P>`%3`GPB<!(`<%(
MB?A(P>\"2,'@'D&)SD@)QTB+A"1X`@``2`'02`.4)(`"``!)`<1,B=!%B=)(
M,?A$,>A-B?5,`>!-B?1)P>T;2<'D!4T)[$V)Q4$!Q$G!Y1Y,B<!(P>@"38GH
M18GD20G`2HT$"DB)^DPQPDP!T#'*3(GA2`'03(GB2,'B!4C!Z1M!`>Q!`=A(
M"<H#?B!,B68(`=!,B4882(D&3(GP2<'N`DC!X!Y(B7X@3`GP1`'82(E&$$B+
MA"2(`@``9$@K!"4H````=`7H3]/__TB!Q)@"``!;74%<05U!7D%?PU"_@```
M`.CBT/__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94,A!(
MB7`@2,=`*`````!(QT`P`````,=`>`````!:PT%62&/"055!5%5(B<532(M/
M*$B)^XT4P4@YT78$2/]',$C!Z!U(`4,P2&-#>$R-8SA(B5,HA<!T3[I`````
M*<(YZ@]/U4P!X$ACRD@Y\',+2(T\"$@Y_G,"#PM,C2P.2#GP=@5,.>AR\$B)
MQ_.DBT-X`=")0WB#^$!U<TB)WRG5Z`[I__],B>Y,C6MX@_T_?C),.>9V!4PY
M[G*^3(UV0$DY]'8%33GT<K"Y$````$R)YX/M0/.E2(G?Z-7H__],B?;KR4AC
MS4PYYG8)28T$#$@YQG*%3#GF<PU(C00.23G$#X)S____3(GG\Z2):WA;74%<
M05U!7L-!5DR-=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,
M00_-C7`!2)A(8];&1`4X@$P!\H/^.'XDN4`````QP$B)URGQ\ZI(B>_H1NC_
M_[D.````,<!,B??SJ^L.N3@````QP$B)URGQ\ZI$B6UP2(GO1(EE=.@:Z/__
M2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`(AC`DB+10"(0P-(BT4(2,'H
M&(A#!$B+10A(P>@0B$,%2(M%"(AC!DB+10B(0P=(BT402,'H&(A#"$B+11!(
MP>@0B$,)2(M%$(AC"DB+11"(0PM(BT482,'H&(A##$B+11A(P>@0B$,-2(M%
M&(AC#DB+11B(0P](BT4@2,'H&(A#$$B+12!(P>@0B$,12(M%((AC$DB+12"(
M0Q-;74%<05U!7NDST/__#Q\`\P\>^DB+!75I``!(@_C_="]52(GE4TB-'6-I
M``!(@^P(#Q^``````/_02(M#^$B#ZPA(@_C_=?!(BUWXR<-FD,-0Z`G3__]8
MPP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M
M<`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R
M;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P!414U01$E2`%1-4``8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@`Q+C`U-`!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H
M=6YK7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F
M("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?
M1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL
M87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I
M8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@
M(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0SL*?0IS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D
M8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R
M;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A
M;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F
M:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN
M9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]
M("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N
M)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q
M6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H
M*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D
M871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\
M+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@
M("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L
M("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C
M*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y
M(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO
M72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN
M97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT
M9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L
M("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F
M:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#
M*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q
M6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@
M/2`A)$5.5GM005)?1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA
M;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92![
M"FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X
M+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q
M6T-A;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N
M=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`
M```!&P,[X````!L```#,@/___````#R$__\D`0``7(3__P`%``"AA___/`$`
M`"J(__^$`0``8HC__YP!``#0B/__Q`$```6*__\(`@``AXK__R0"```DC/__
M<`(``$^,__^(`@``DXS__Z`"``!XC?__U`(``'V-___H`@``&(___S0#```N
MC___2`,``->/__]L`P``?)'__Z@#``#`D?__P`,``->1___8`P``:9+__R0$
M```UF/__H`0``'&:___,!```P)K__R0%``#?L/__<`4``"VQ__^(!0``)++_
M_\0%```4``````````%Z4@`!>!`!&PP'")`!```D````'````,A___]P`P``
M``X01@X82@\+=PB``#\:.RHS)"(`````%````$0````0@___&```````````
M````1````%P```!=AO__B0````!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&
M00XX@P=!#D`";0XX1`XP00XH0@X@0@X80@X00@X(%````*0```">AO__.```
M``!$#B!S#@@`)````+P```"^AO__;@````!!#A"&`D$.&(,#1PXP`F(.&$$.
M$$$."$````#D````!(?__S4!````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#
M!D<.T`$#'0$.,$$.*$$.($(.&$(.$$(."```&````"@!``#UA___@@````!'
M#L`!`GH."````$@```!$`0``6XC__YT!````0@X0CP)"#AB.`T(.((T$0@XH
MC`5!#C"&!D0..(,'1PY0`WX!#CA!#C!!#BA"#B!"#AA"#A!"#@@````4````
MD`$``*R)__\K`````$$.$%0."``4````J`$``+^)__]$`````$$.$&H."``P
M````P`$``.N)___E`````$(.$(P"00X8A@-!#B"#!$<.L$`"U0X@00X800X0
M0@X(````$````/0!``"<BO__!0````````!(````"`(``(V*__^;`0```$(.
M$(\"0@X8C@-"#B"-!$(.*(P%2PXPA@9$#CB#!T<.X"$#;P$..$0.,$$.*$(.
M($(.&$(.$$(."```$````%0"``#<B___%@`````````@````:`(``-Z+__^I
M`````$H.$(8"`DP*Q@X(0@L"1`X(0<8X````C`(``&.,__^E`0```$(.$(X"
M50X8C0-)#B",!$@.*(8%2PY@`VH!#BA!#B!"#AA"#A!"#@@````4````R`(`
M`,R-__]$`````$H.$'(."``4````X`(``/B-__\7`````$$.$%4."`!(````
M^`(``/>-__^2`````$(.$(T"2PX8C`-'#B"&!$$.*(,%00XP`F0*#BA$#B!#
M#AA"#A!"#@A%"T$.*$$.($$.&$(.$$(."```>````$0#```]CO__S`4```!"
M#A"/`E$.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#I"#`@*;"@XX1`XP00XH
M0@X@0@X80@X00@X(10L#F`0.F(,"2PZ@@P)+#IB#`D$.D(,"`D(..$0.,$$.
M*$(.($(.&$(.$$(."````"@```#``P``C9/__SP"````0@X0C`)'#AB&`T$.
M((,$`RX"#AA!#A!"#@@`,````.P#``"=E?__3P````!!#A"&`D0.&(,#00X@
M>PH.&$0.$$$."$4+00X800X000X(`"`````@!```5'___ZL!````0@X0C`)$
M#C`#GP$.$$4."````$@```!$!```E)7__Q\6````0@X0CP)'#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[0!0/^%0XX00XP00XH0@X@0@X80@X00@X(```4
M````D`0``&>K__].`````$$.$`),#@@X````J`0``)VK___W`````$(.$(X"
M10X8C0-"#B",!$$.*(8%1`XP@P8"X0XH00X@0@X80@X00@X(```X````Y`0`
M`%BL__]%`0```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#*@$.*$$.($(.
M&$(.$$(."```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/__________``````````#_____
M_____P`````````````````````!`````````-H"`````````0````````#E
M`@````````\`````````$`0````````,```````````@````````#0``````
M``#Q4@```````/7^_V\`````,`,````````%`````````!`-````````!@``
M```````H!`````````H`````````+@0````````+`````````!@`````````
M%0````````````````````,`````````^+T````````"`````````!`%````
M````%``````````'`````````!<`````````"!,````````'`````````$`1
M````````"`````````#(`0````````D`````````&``````````8````````
M````````````^___;P`````!```(`````/G__V\`````!P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````%B\````````````````
M`````````````"8@````````-B````````!&(````````%8@````````9B``
M``````!V(````````(8@````````EB````````"F(````````+8@````````
MQB````````#6(````````.8@````````]B`````````&(0```````!8A````
M````)B$````````V(0```````$8A````````5B$```````!F(0```````'8A
M````````AB$```````"6(0```````*8A````````MB$```````#&(0``````
M`-8A````````YB$```````#V(0````````8B````````%B(````````F(@``
M`````#8B````````1B(```````!6(@```````&8B````````=B(```````"&
M(@```````)8B````````IB(```````"V(@```````,8B````````UB(`````
M``#F(@```````/8B````````!B,````````6(P```````"8C````````-B,`
M``````!&(P```````%8C````````9B,```````!V(P``````````````````
M````````````````````````````````````````````````````````````
M````````````````P````````````````````````````````````````.)@
M````````VV`````````>8@```````/A@````````)F(`````````````````
M`/____\`````MF(```````!'0T,Z("A!;'!I;F4@,3$N,BXQ7V=I=#(P,C(P
M,C$Y*2`Q,2XR+C$@,C`R,C`R,3D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+F=N=2YP<F]P97)T>0`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD
M871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````X`(```````#@`@``````
M`!D````````````````````!````````````````````$P````<````"````
M```````#``````````,````````P````````````````````"```````````
M`````````"8```#V__]O`@`````````P`P```````#`#````````^```````
M```$``````````@````````````````````P````"P````(`````````*`0`
M```````H!````````.@(````````!0````$````(`````````!@`````````
M.`````,````"`````````!`-````````$`T````````N!```````````````
M`````0```````````````````$`````$`````@````````!`$0```````$`1
M````````R`$````````$``````````@`````````&`````````!*````!```
M`$(`````````"!,````````($P```````!`%````````!````!0````(````
M`````!@`````````5`````$````&```````````@`````````"`````````-
M`````````````````````0```````````````````$\````!````!@``````
M```0(````````!`@````````<`,``````````````````!``````````$```
M``````!:`````0````8`````````@",```````"`(P```````!@`````````
M```````````(``````````@`````````8P````$````&`````````*`C````
M````H",```````!1+P``````````````````$````````````````````&D`
M```!````!@````````#Q4@```````/%2````````"```````````````````
M``$```````````````````!O`````0````(``````````&``````````8```
M`````$(_```````````````````(````````````````````=P````$````"
M`````````$2?````````1)\```````#D````````````````````!```````
M`````````````(4````!`````@`````````HH````````"B@````````(`4`
M``````````````````@```````````````````"/`````0````,`````````
M,+P````````PK````````!`````````````````````(````````````````
M````E@````$````#`````````$"\````````0*P````````0````````````
M````````"````````````````````)T````!`````P````````!0O```````
M`%"L````````"````````````````````!````````````````````"J````
M!@````,`````````6+P```````!8K````````*`!````````!0`````````(
M`````````!``````````7@````$````#`````````/B]````````^*T`````
M```(`@``````````````````"``````````(`````````+,````!`````P``
M````````P`````````"P````````8````````````````````"``````````
M``````````"Y````"`````,`````````8,````````!@L````````,`0````
M```````````````@````````````````````O@````$````P````````````
M````````8+`````````Q`````````````````````0`````````!````````
M``$````#`````````````````````````)&P````````QP``````````````
4``````$`````````````````````
